<?php

namespace ipl\Sql;

use InvalidArgumentException;

use function ipl\Stdlib\get_php_type;

/**
 * SQL connection configuration
 */
class Config
{
    /**
     * Create a new SQL connection configuration from the given configuration key-value pairs
     *
     * @param iterable $config Configuration key-value pairs
     *
     * @throws InvalidArgumentException If $config is not iterable
     */
    public function __construct($config)
    {
        if (! is_iterable($config)) {
            throw new InvalidArgumentException(sprintf(
                '%s expects parameter one to be iterable, got %s instead',
                __METHOD__,
                get_php_type($config)
            ));
        }

        foreach ($config as $key => $value) {
            $this->$key = $value;
        }
    }

    /** @var string Database type */
    public $type;

    /** @var string Type of the DBMS */
    public $db;

    /** @var string Database host */
    public $host;

    /** @var int Database port */
    public $port;

    /** @var string Database name */
    public $dbname;

    /** @var string Username to use for authentication */
    public $username;

    /** @var string Password to use for authentication */
    public $password;

    /** @var bool Use SSL for connection */
    public $use_ssl;

    /** @var bool Don't verify SSL cerificate */
    public $ssl_do_not_verify_server_cert;

    /** @var string Path to SSL certificate */
    public $ssl_cert;

    /** @var string Path to SSL key */
    public $ssl_key;

    /** @var string Path to SSL CA file */
    public $ssl_ca;

    /** @var string Path to SSL CA directory */
    public $ssl_capath;

    /** @var string SSL ciphers */
    public $ssl_cipher;

    /**
     * Character set for the connection
     *
     * If you want to use the default charset as configured by the database, don't set this property.
     *
     * @var string
     */
    public $charset;

    /**
     * PDO connect options
     *
     * Array of key-value pairs that should be set when calling {@link Connection::connect()} in order to establish a DB
     * connection.
     *
     * @var array
     */
    public $options;
}
